@@ -5,9 +5,9 @@ import re
 from .aws import AWSIE
 from ..networking.exceptions import HTTPError
 from ..utils import (
-    clean_html,
     ExtractorError,
     InAdvancePagedList,
+    clean_html,
     int_or_none,
     parse_iso8601,
     str_or_none,
@@ -63,17 +63,17 @@ class ShahidIE(ShahidBaseIE):
         'params': {
             # m3u8 download
             'skip_download': True,
-        }
+        },
     }, {
         'url': 'https://shahid.mbc.net/ar/movies/%D8%A7%D9%84%D9%82%D9%86%D8%A7%D8%B5%D8%A9/movie-151746',
-        'only_matching': True
+        'only_matching': True,
     }, {
         # shahid plus subscriber only
         'url': 'https://shahid.mbc.net/ar/series/%D9%85%D8%B1%D8%A7%D9%8A%D8%A7-2011-%D8%A7%D9%84%D9%85%D9%88%D8%B3%D9%85-1-%D8%A7%D9%84%D8%AD%D9%84%D9%82%D8%A9-1/episode-90511',
-        'only_matching': True
+        'only_matching': True,
     }, {
         'url': 'https://shahid.mbc.net/en/shows/Ramez-Fi-Al-Shallal-season-1-episode-1/episode-359319',
-        'only_matching': True
+        'only_matching': True,
     }]
 
     def _perform_login(self, username, password):
@@ -84,7 +84,7 @@ class ShahidIE(ShahidBaseIE):
                     'email': username,
                     'password': password,
                     'basic': 'false',
-                }).encode('utf-8'), headers={
+                }).encode(), headers={
                     'Content-Type': 'application/json; charset=UTF-8',
                 })['user']
         except ExtractorError as e:
@@ -127,7 +127,7 @@ class ShahidIE(ShahidBaseIE):
         #     })['productModel']
 
         response = self._download_json(
-            'http://api.shahid.net/api/v1_1/%s/%s' % (page_type, video_id),
+            f'http://api.shahid.net/api/v1_1/{page_type}/{video_id}',
             video_id, 'Downloading video JSON', query={
                 'apiKey': 'sh@hid0nlin3',
                 'hash': 'b2wMCTHpSmyxGqQjJFOycRmLSex+BpTK/ooxy6vHaqs=',
@@ -136,7 +136,7 @@ class ShahidIE(ShahidBaseIE):
         error = data.get('error')
         if error:
             raise ExtractorError(
-                '%s returned error: %s' % (self.IE_NAME, '\n'.join(error.values())),
+                '{} returned error: {}'.format(self.IE_NAME, '\n'.join(error.values())),
                 expected=True)
 
         video = data[page_type]
@@ -175,7 +175,7 @@ class ShahidShowIE(ShahidBaseIE):
         'playlist_mincount': 32,
     }, {
         'url': 'https://shahid.mbc.net/ar/series/How-to-live-Longer-(The-Big-Think)/series-291861',
-        'only_matching': True
+        'only_matching': True,
     }]
     _PAGE_SIZE = 30
 
@@ -196,7 +196,7 @@ class ShahidShowIE(ShahidBaseIE):
                     'pageSize': 30,
                     'sorts': [{
                         'order': 'DESC',
-                        'type': 'SORTDATE'
+                        'type': 'SORTDATE',
                     }],
                 })
             for product in playlist.get('productList', {}).get('products', []):
