@@ -1,7 +1,7 @@
 from .nbc import NBCIE
 
 
-class USANetworkIE(NBCIE):
+class USANetworkIE(NBCIE):  # XXX: Do not subclass from concrete IE
     _VALID_URL = r'https?(?P<permalink>://(?:www\.)?usanetwork\.com/(?:[^/]+/videos?|movies?)/(?:[^/]+/)?(?P<id>\d+))'
     _TESTS = [{
         'url': 'https://www.usanetwork.com/peacock-trailers/video/intelligence-trailer/4185302',
